Common, neocortex-v5 and neocortex-v6 mod files are merged. Below are the sources.

Common mods repository: hpc/sim/models/common.git
Common mods git hash: bfe26c3d

Neocortex mods repository: hpc/sim/models/neocortex.git
Neocortex mods git hash: 7feb8d9
